/*!	\file	TT_Phase_4_main.cpp
	\author	Garth Santor
	\date	2024-01-03

	Temperature Table with dynamic columns.

	MSVC:	/std:c++20
	g++:	-m64 -std=c++20
*/

#include <iostream>
#include <iomanip>
#include <cmath>
using namespace std;


constexpr double fahr_to_cel(double fahrenheit) {
	return 5.0 / 9.0 * (fahrenheit - 32.0);
}


inline int num_whole_digits(double number) {
	return (int)floor(log10(abs(number))) + 1;
}


int main() {
	// Get table parameters from the user
	cout << "Temperature Table 1.0.0: (c) 2020-24, Garth Santor\n";
	cout << "Enter a low and high Fahrenheit temperature and interval: ";
	double fahr_start{ -40.0 };
	double fahr_end{ 140.0 };
	double fahr_interval{ 10.0 };
	cin >> fahr_start >> fahr_end >> fahr_interval;

	// correct interval direction
	fahr_interval = abs(fahr_interval);
	if (fahr_start > fahr_end) {
		fahr_interval = -fahr_interval;
	}
	bool descending_table = fahr_interval < 0;


	// column width is the maximum # of digits +1 for '.', +1 for fraction, +1 for padding
	const int fcw{ max(num_whole_digits(fahr_start), num_whole_digits(fahr_end)) + 3 };
	const int ccw{ max(num_whole_digits(fahr_to_cel(fahr_start)), num_whole_digits(fahr_to_cel(fahr_end))) + 3 };


	// Output the table
	cout << fixed << setprecision(1);
	for (double fahr_temp{ fahr_start };
		descending_table ? fahr_temp >= fahr_end : fahr_temp <= fahr_end;
		fahr_temp += fahr_interval)
	{
		const double celc_temp{ 5.0 / 9.0 * (fahr_temp - 32.0) };
		cout << setw(fcw) << fahr_temp << " F " << setw(ccw) << celc_temp << " C\n";
	}
}